@@ -4,13 +4,13 @@ var searchData=
   ['jxlbasicinfo_1',['JxlBasicInfo',['../structJxlBasicInfo.html',1,'']]],
   ['jxlbitdepth_2',['JxlBitDepth',['../structJxlBitDepth.html',1,'']]],
   ['jxlblendinfo_3',['JxlBlendInfo',['../structJxlBlendInfo.html',1,'']]],
-  ['jxlbutteraugliapidestroystruct_4',['JxlButteraugliApiDestroyStruct',['../structJxlButteraugliApiDestroyStruct.html',1,'']]],
-  ['jxlbutteraugliresultdestroystruct_5',['JxlButteraugliResultDestroyStruct',['../structJxlButteraugliResultDestroyStruct.html',1,'']]],
-  ['jxlcmsinterface_6',['JxlCmsInterface',['../structJxlCmsInterface.html',1,'']]],
-  ['jxlcolorencoding_7',['JxlColorEncoding',['../structJxlColorEncoding.html',1,'']]],
-  ['jxlcolorprofile_8',['JxlColorProfile',['../structJxlColorProfile.html',1,'']]],
-  ['jxldecoderdestroystruct_9',['JxlDecoderDestroyStruct',['../structJxlDecoderDestroyStruct.html',1,'']]],
-  ['jxlencoderdestroystruct_10',['JxlEncoderDestroyStruct',['../structJxlEncoderDestroyStruct.html',1,'']]],
+  ['jxlchunkedframeinputsource_4',['JxlChunkedFrameInputSource',['../structJxlChunkedFrameInputSource.html',1,'']]],
+  ['jxlcmsinterface_5',['JxlCmsInterface',['../structJxlCmsInterface.html',1,'']]],
+  ['jxlcolorencoding_6',['JxlColorEncoding',['../structJxlColorEncoding.html',1,'']]],
+  ['jxlcolorprofile_7',['JxlColorProfile',['../structJxlColorProfile.html',1,'']]],
+  ['jxldecoderdestroystruct_8',['JxlDecoderDestroyStruct',['../structJxlDecoderDestroyStruct.html',1,'']]],
+  ['jxlencoderdestroystruct_9',['JxlEncoderDestroyStruct',['../structJxlEncoderDestroyStruct.html',1,'']]],
+  ['jxlencoderoutputprocessor_10',['JxlEncoderOutputProcessor',['../structJxlEncoderOutputProcessor.html',1,'']]],
   ['jxlextrachannelinfo_11',['JxlExtraChannelInfo',['../structJxlExtraChannelInfo.html',1,'']]],
   ['jxlframeheader_12',['JxlFrameHeader',['../structJxlFrameHeader.html',1,'']]],
   ['jxlheaderextensions_13',['JxlHeaderExtensions',['../structJxlHeaderExtensions.html',1,'']]],
